@@ -28,7 +28,8 @@ public class StepFactory {
      * Private sole constructor.
      */
     private StepFactory() {
-        filterFactory_ = new ObjectFactory( ProcessingFilter.class );
+        filterFactory_ =
+            new ObjectFactory<ProcessingFilter>( ProcessingFilter.class );
         String pkg = "uk.ac.starlink.ttools.filter.";
         filterFactory_.register( "addcol", pkg + "AddColumnFilter" );
         filterFactory_.register( "addpixsample", pkg + "PixSampleFilter" );
@@ -47,6 +48,7 @@ public class StepFactory {
         filterFactory_.register( "explodeall", pkg + "ExplodeAllFilter" );
         filterFactory_.register( "fixcolnames", pkg + "FixNamesFilter" );
         filterFactory_.register( "head", pkg + "HeadFilter" );
+        filterFactory_.register( "healpixmeta", pkg + "HealpixMetadataFilter" );
         filterFactory_.register( "keepcols", pkg + "KeepColumnFilter" );
         filterFactory_.register( "meta", pkg + "MetadataFilter" );
         filterFactory_.register( "progress", pkg + "ProgressFilter" );
@@ -100,7 +102,7 @@ public class StepFactory {
     /**
      * Creates a processing filter from a line of text.
      * The general format for the line is 
-     * <code>&lt;filter-name&gt; &lt;ilter-args&gt;</code>
+     * <code>&lt;filter-name&gt; &lt;filter-args&gt;</code>
      *
      * @param   line  line of text representing filter commands
      * @return  processing step; may be null if <code>line</code>
