@@ -2,10 +2,14 @@ package uk.ac.starlink.ttools.filter;
 
 import java.io.IOException;
 import java.util.LinkedList;
+import uk.ac.starlink.table.AccessRowSequence;
 import uk.ac.starlink.table.IteratorRowSequence;
-import uk.ac.starlink.table.RandomRowSequence;
+import uk.ac.starlink.table.RowAccess;
 import uk.ac.starlink.table.RowSequence;
+import uk.ac.starlink.table.RowSplittable;
 import uk.ac.starlink.table.StarTable;
+import uk.ac.starlink.table.Tables;
+import uk.ac.starlink.table.WrapperRowAccess;
 import uk.ac.starlink.table.WrapperStarTable;
 
 /**
@@ -48,9 +52,19 @@ public class TailTable extends WrapperStarTable {
         return super.getRowCount() - getRowCount() + irow;
     }
 
+    public RowAccess getRowAccess() throws IOException {
+        final long ioff = super.getRowCount() - getRowCount();
+        return new WrapperRowAccess( super.getRowAccess() ) {
+            @Override
+            public void setRowIndex( long irow ) throws IOException {
+                super.setRowIndex( ioff + irow );
+            }
+        };
+    }
+
     public RowSequence getRowSequence() throws IOException {
         if ( isRandom() ) {
-            return new RandomRowSequence( this );
+            return AccessRowSequence.createInstance( this );
         }
         else {
             long nbase = super.getRowCount();
@@ -77,4 +91,8 @@ public class TailTable extends WrapperStarTable {
             }
         }
     }
+
+    public RowSplittable getRowSplittable() throws IOException {
+        return Tables.getDefaultRowSplittable( this );
+    }
 }
