@@ -2,7 +2,10 @@ package uk.ac.starlink.ttools.mode;
 
 import java.io.IOException;
 import java.io.PrintStream;
+import uk.ac.starlink.table.RowCollector;
+import uk.ac.starlink.table.RowRunner;
 import uk.ac.starlink.table.RowSequence;
+import uk.ac.starlink.table.RowSplittable;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.task.Environment;
 import uk.ac.starlink.task.ExecutionException;
@@ -19,6 +22,24 @@ import uk.ac.starlink.ttools.TableConsumer;
  */
 public class CountMode implements ProcessingMode {
 
+    private final boolean isParallel_;
+
+    /**
+     * Constructs an instance with default parallelism.
+     */
+    public CountMode() {
+        this( true );
+    }
+
+    /**
+     * Constructs an instance with specified paralellism.
+     *
+     * @param  isParallel  true to count in parallel where possible
+     */
+    public CountMode( boolean isParallel ) {
+        isParallel_ = isParallel;
+    }
+
     public Parameter<?>[] getAssociatedParameters() {
         return new Parameter<?>[ 0 ];
     }
@@ -46,22 +67,35 @@ public class CountMode implements ProcessingMode {
      * @param  table  table
      * @return  short summary of rows and columns in the table
      */
-    private static String getSummary( StarTable table )
+    private String getSummary( StarTable table )
             throws IOException {
         int ncol = table.getColumnCount();
         long nrow = table.getRowCount();
         if ( nrow < 0L ) {
-            nrow = 0L;
-            RowSequence rseq = table.getRowSequence();
-            try {
-                while ( rseq.next() ) {
-                    nrow++;
-                }
-            }
-            finally {
-                rseq.close();
-            }
+            RowRunner runner = isParallel_ ? RowRunner.DEFAULT
+                                           : RowRunner.SEQUENTIAL;
+            nrow = runner.collect( new CountCollector(), table )[ 0 ];
         }
         return "columns: " + ncol + "   rows: " + nrow;
     }
+
+    /**
+     * Collector implementation for counting rows.
+     */
+    private static class CountCollector extends RowCollector<long[]> {
+        public long[] createAccumulator() {
+            return new long[ 1 ];
+        }
+        public long[] combine( long[] acc1, long[] acc2 ) {
+            return new long[] { acc1[ 0 ] + acc2[ 0 ] };
+        }
+        public void accumulateRows( RowSplittable rseq, long[] acc )
+                throws IOException {
+            long nrow = 0;
+            while ( rseq.next() ) {
+                nrow++;
+            }
+            acc[ 0 ] += nrow;
+        }
+    }
 }
