@@ -7,8 +7,11 @@ import uk.ac.starlink.table.BeanStarTable;
 import uk.ac.starlink.table.ColumnInfo;
 import uk.ac.starlink.table.DefaultValueInfo;
 import uk.ac.starlink.table.DescribedValue;
-import uk.ac.starlink.table.RowSequence;
+import uk.ac.starlink.table.RowCollector;
+import uk.ac.starlink.table.RowRunner;
+import uk.ac.starlink.table.RowSplittable;
 import uk.ac.starlink.table.StarTable;
+import uk.ac.starlink.table.Tables;
 import uk.ac.starlink.table.ValueInfo;
 import uk.ac.starlink.table.formats.TextTableWriter;
 import uk.ac.starlink.task.Environment;
@@ -26,9 +29,33 @@ import uk.ac.starlink.ttools.filter.StatsFilter;
  */
 public class StatsMode implements ProcessingMode {
 
+    private final boolean isParallel_;
+
     private static final ValueInfo ROWCOUNT_INFO = 
         new DefaultValueInfo( "Total Rows", Long.class );
 
+    /**
+     * Default constructor.
+     */
+    public StatsMode() {
+        this( true );
+    }
+
+    /**
+     * Constructs an instance with optional parallel processing.
+     * Parallel execution can be much faster, but it depends on the
+     * underlying data; if the multithreaded execution ends up
+     * requesting simultaneous access to many different parts of
+     * a mapped file, it can end up being much slower than
+     * sequential execution.
+     *
+     * @param   isParallel  whether statistics calculations are
+     *                      done using multiple threads
+     */
+    public StatsMode( boolean isParallel ) {
+        isParallel_ = isParallel;
+    }
+
     public Parameter<?>[] getAssociatedParameters() {
         return new Parameter<?>[ 0 ];
     }
@@ -54,6 +81,8 @@ public class StatsMode implements ProcessingMode {
 
     public TableConsumer createConsumer( Environment env ) {
         final PrintStream out = env.getOutputStream();
+        final RowRunner runner = isParallel_ ? RowRunner.DEFAULT
+                                             : RowRunner.SEQUENTIAL;
         return new TableConsumer() {
             public void consume( StarTable table ) throws IOException {
                 /* Create a table which contains all the statistics, and
@@ -62,8 +91,8 @@ public class StatsMode implements ProcessingMode {
                  * around for manipulation and output of tables, it turns out
                  * to be convenient to use them rather than to write a 
                  * statistics outputter from scratch. */
-                new TextTableWriter().writeStarTable( makeStatsTable( table ),
-                                                      out );
+                new TextTableWriter()
+                   .writeStarTable( makeStatsTable( table, runner ), out );
             }
         };
     }
@@ -73,35 +102,17 @@ public class StatsMode implements ProcessingMode {
      * of another table.
      *
      * @param   table  table whose stats are to be calculated
+     * @param   runner  handles row-based execution
      * @return   table containing statistics of <tt>table</tt>
      */
-    private static StarTable makeStatsTable( StarTable table )
+    private static StarTable makeStatsTable( StarTable table, RowRunner runner )
             throws IOException {
 
-        /* Get an array of objects each of which can accumulate the
-         * statistics for one column of the base table. */
-        int ncol = table.getColumnCount();
-        ColStats[] stats = new ColStats[ ncol ];
-        for ( int icol = 0; icol < ncol; icol++ ) {
-            stats[ icol ] =
-                ColStats.makeColStats( table.getColumnInfo( icol ) );
-        }
-
-        /* Accumulate the statistics. */
-        RowSequence rseq = table.getRowSequence();
-        long nrow = 0;
-        try {
-            while ( rseq.next() ) {
-                nrow++;
-                Object[] row = rseq.getRow();
-                for ( int icol = 0; icol < ncol; icol++ ) {
-                    stats[ icol ].acceptDatum( row[ icol ] );
-                }
-            }
-        }
-        finally {
-            rseq.close();
-        }
+        /* Calculate the statistics. */
+        StatsCollector collector =
+            new StatsCollector( Tables.getColumnInfos( table ) );
+        TableStats tstats = runner.collect( collector, table );
+        long nrow = tstats.nrow_;
 
         /* Turn the array of ColStats objects into a StarTable. */
         StarTable statsTable;
@@ -113,7 +124,7 @@ public class StatsMode implements ProcessingMode {
                   new AssertionError( "Introspection Error???" )
                  .initCause( e );
         }
-        ((BeanStarTable) statsTable).setData( stats );
+        ((BeanStarTable) statsTable).setData( tstats.colStats_ );
 
         /* Unfortunately, a BeanTable returns its columns in an unhelpful
          * order (alphabetical by property/column name), so we reorder
@@ -134,4 +145,75 @@ public class StatsMode implements ProcessingMode {
         return statsTable;
     }
 
+    /**
+     * Accumulator for table column statistics.
+     */
+    private static class TableStats {
+        final int nc_;
+        final ColStats[] colStats_;
+        long nrow_;
+
+        /**
+         * Constructor.
+         *
+         * @param  infos   metadata object for each column
+         *                 that will be accumulated
+         */
+        TableStats( ColumnInfo[] infos ) {
+            nc_ = infos.length;
+            colStats_ = new ColStats[ nc_ ];
+            for ( int ic = 0; ic < nc_; ic++ ) {
+                colStats_[ ic ] = ColStats.makeColStats( infos[ ic ] );
+            }
+        }
+
+        /**
+         * Accumulate the contents of a second stats object into this one.
+         *
+         * @param  other  other table stats
+         */
+        void addStats( TableStats other ) {
+            this.nrow_ += other.nrow_;
+            for ( int ic = 0; ic < nc_; ic++ ) {
+                this.colStats_[ ic ].addStats( other.colStats_[ ic ] );
+            }
+        }
+    }
+
+    /**
+     * Collector for accumulating column statitics.
+     */
+    private static class StatsCollector extends RowCollector<TableStats> {
+        private final ColumnInfo[] infos_;
+        private final int nc_;
+     
+        /**
+         * Constructor.
+         *
+         * @param  infos   metadata object for each column
+         *                 that will be accumulated
+         */
+        StatsCollector( ColumnInfo[] infos ) {
+            infos_ = infos;
+            nc_ = infos.length;
+        }
+        public TableStats createAccumulator() {
+            return new TableStats( infos_ );
+        }
+        public TableStats combine( TableStats tstats1, TableStats tstats2 ) {
+            tstats1.addStats( tstats2 );
+            return tstats1;
+        }
+        public void accumulateRows( RowSplittable rseq, TableStats tstats )
+                throws IOException {
+            ColStats[] cstats = tstats.colStats_;
+            while ( rseq.next() ) {
+                Object[] row = rseq.getRow();
+                for ( int ic = 0; ic < nc_; ic++ ) {
+                    cstats[ ic ].acceptDatum( row[ ic ] );
+                }
+                tstats.nrow_++;
+            }
+        }
+    }
 }
