@@ -45,6 +45,8 @@ import uk.ac.starlink.util.SplitCollector;
 public class PlotUtil {
 
     private static Boolean dfltAntialias_;
+    private static final DecimalFormatSymbols UK_SYMBOLS =
+        DecimalFormatSymbols.getInstance( Locale.UK );
     private static final Logger logger_ =
         Logger.getLogger( "uk.ac.starlink.ttools.plot2" );
 
@@ -506,7 +508,7 @@ public class PlotUtil {
                                                boolean[] logFlags,
                                                boolean doPad,
                                                DataStore dataStore ) {
-        int nDataDim = ranges.length;
+        final int nDataDim = ranges.length;
 
         /* Create a point cloud containing all the data coordinates
          * represented by the supplied layers.  If there are several
@@ -518,19 +520,28 @@ public class PlotUtil {
         SubCloud[] subClouds =
             arrayConcat( SubCloud.createSubClouds( layers, true ),
                          SubCloud.createPartialSubClouds( layers, true ) );
-        if ( subClouds.length == 0 ) {
-            return;
-        }
-        PointCloud cloud = new PointCloud( subClouds );
+        if ( subClouds.length > 0 ) {
+            PointCloud cloud = new PointCloud( subClouds );
 
-        /* Collect values for the represented points to mark out the basic
-         * range of data positions covered by the layers. */
-        RangeCollector rangeCollector = new RangeCollector( nDataDim );
-        Range[] cloudRanges =
-            dataStore.getTupleRunner().coordRunner()
-                     .collect( rangeCollector, 
-                               cloud.createDataPosSupplier( dataStore ) );
-        rangeCollector.mergeRanges( ranges, cloudRanges );
+            /* Collect values for the represented points to mark out the basic
+             * range of data positions covered by the layers. */
+            RangeCollector<CoordSequence> rangeCollector =
+                    new RangeCollector<CoordSequence>( nDataDim ) {
+                public void accumulate( CoordSequence cseq, Range[] ranges ) {
+                    double[] dpos = cseq.getCoords();
+                    while ( cseq.next() ) {
+                        for ( int idim = 0; idim < nDataDim; idim++ ) {
+                            ranges[ idim ].submit( dpos[ idim ] );
+                        }
+                    }
+                }
+            };
+            Range[] cloudRanges =
+                dataStore.getTupleRunner().coordRunner()
+                         .collect( rangeCollector, 
+                                   cloud.createDataPosSupplier( dataStore ) );
+            rangeCollector.mergeRanges( ranges, cloudRanges );
+        }
 
         /* If any of the layers wants to supply non-data-position points
          * to mark out additional space, take account of those too. */
@@ -997,9 +1008,7 @@ public class PlotUtil {
      */
     public static String formatNumber( double value, String baseFmt,
                                        int nFracDigits ) {
-        DecimalFormat fmt =
-           new DecimalFormat( baseFmt,
-                              DecimalFormatSymbols.getInstance( Locale.UK ) );
+        DecimalFormat fmt = new DecimalFormat( baseFmt, UK_SYMBOLS );
         fmt.setMaximumFractionDigits( nFracDigits );
         fmt.setMinimumFractionDigits( nFracDigits );
         String out = fmt.format( value );
@@ -1008,6 +1017,68 @@ public class PlotUtil {
              : out;
     }
 
+    /**
+     * Numeric formatting utility function for writing a given number
+     * of significant figures.
+     * The output is not Locale-sensitive, so is suitable for formatting
+     * numbers that may be re-parsed as numbers (by non-Locale-sensitive code).
+     * Formatting is best-efforts and may suppress insignificant zeros.
+     *
+     * @param  value  numeric value to format
+     * @param  nsf   (approximate) number of significant figures
+     * @return  formatted string
+     */
+    public static String formatNumberSf( double value, int nsf ) {
+        String txt = doFormatNumberSf( value, nsf );
+        assert Double.isNaN( value ) || Double.isInfinite( value ) || value == 0
+            || Math.abs( ( value - Double.parseDouble( txt ) ) / value )
+               < Math.pow( 10, - ( nsf - 1 ) )
+               : "nsf: " + nsf + "\t" + value + " -> " + txt;
+        return txt;
+    }
+
+    /**
+     * Does the work for {@link #formatNumberSf}.
+     *
+     * @param  value  numeric value to format
+     * @param  nsf   (approximate) number of significant figures
+     * @return  formatted string
+     */
+    private static String doFormatNumberSf( double value, int nsf ) { 
+        if ( value == 0 ) {
+            return "0";
+        }
+        else if ( Double.isNaN( value ) || Double.isInfinite( value ) ) {
+            return Double.toString( value );
+        }
+        else {
+            double absVal = Math.abs( value );
+            double log10 = Math.log10( absVal );
+            if ( log10 >= -1 && log10 < nsf ) {
+                int ndp = nsf - (int) Math.ceil( log10 );
+                StringBuffer fbuf = new StringBuffer( 2 + ndp );
+                fbuf.append( "0." );
+                for ( int i = 0; i < ndp; i++ ) {
+                    fbuf.append( '#' );
+                }
+                DecimalFormat fmt =
+                    new DecimalFormat( fbuf.toString(), UK_SYMBOLS );
+                return fmt.format( value );
+            }
+            else {
+                StringBuffer fbuf = new StringBuffer( 4 + nsf );
+                fbuf.append( "0." );
+                for ( int i = 0; i < nsf - 1; i++ ) {
+                    fbuf.append( '#' );
+                }
+                fbuf.append( "E0" );
+                DecimalFormat fmt =
+                    new DecimalFormat( fbuf.toString(), UK_SYMBOLS );
+                return fmt.format( value );
+            }
+        }
+    }
+
     /**
      * Formats a number so that it presents a number of significant figures
      * corresponding to a supplied small difference.
@@ -1148,59 +1219,6 @@ public class PlotUtil {
                               base.height - insets.top - insets.bottom );
     }
 
-    /**
-     * SplitCollector implementation that can accumulate range information
-     * from a CoordSequence.
-     */
-    private static class RangeCollector
-            implements SplitCollector<CoordSequence,Range[]> {
-
-        private final int ndim_;
-
-        /**
-         * Constructor.
-         *
-         * @param  ndim  number of range objects (data dimensions)
-         */
-        public RangeCollector( int ndim ) {
-            ndim_ = ndim;
-        }
-
-        public Range[] createAccumulator() {
-            Range[] ranges = new Range[ ndim_ ];
-            for ( int i = 0; i < ndim_; i++ ) {
-                ranges[ i ] = new Range();
-            }
-            return ranges;
-        }
-
-        public void accumulate( CoordSequence cseq, Range[] ranges ) {
-            double[] dpos = cseq.getCoords();
-            while ( cseq.next() ) {
-                for ( int idim = 0; idim < ndim_; idim++ ) {
-                    ranges[ idim ].submit( dpos[ idim ] );
-                }
-            }
-        }
-
-        public Range[] combine( Range[] ranges1, Range[] ranges2 ) {
-            mergeRanges( ranges1, ranges2 );
-            return ranges1;
-        }
-
-        /**
-         * Merges the content of the second range into the first one.
-         *
-         * @param  ranges0  first input range, modified on exit
-         * @param  ranges1  second input range, unmodified on exit
-         */
-        public void mergeRanges( Range[] ranges0, Range[] ranges1 ) {
-            for ( int i = 0; i < ndim_; i++ ) {
-                ranges0[ i ].extend( ranges1[ i ] );
-            }
-        }
-    }
-
     /**
      * Accumulator class for use with ClosestCollector.
      * Aggregates the index of the current best row with its distance
