@@ -1,6 +1,8 @@
 package uk.ac.starlink.ttools.plot2.data;
 
+import java.util.function.Function;
 import uk.ac.starlink.table.DomainMapper;
+import uk.ac.starlink.table.ValueInfo;
 
 /**
  * Coord implementation for single boolean values.
@@ -10,6 +12,10 @@ import uk.ac.starlink.table.DomainMapper;
  */
 public class BooleanCoord extends SingleCoord {
 
+    private static final SimpleDomain<Boolean> BOOLEAN_DOMAIN =
+        new SimpleDomain<Boolean>( Boolean.class, "Boolean", "boolean",
+                                   "Boolean value" );
+
     /**
      * Constructor.
      *
@@ -17,13 +23,15 @@ public class BooleanCoord extends SingleCoord {
      * @param   isRequired  true if this coordinate is required for plotting
      */
     public BooleanCoord( InputMeta meta, boolean isRequired ) {
-        super( meta, isRequired, Boolean.class, StorageType.BOOLEAN, null );
+        super( meta, isRequired, BOOLEAN_DOMAIN, StorageType.BOOLEAN );
     }
 
-    public Object inputToStorage( Object[] inputValues,
-                                  DomainMapper[] mappers ) {
-        Object c = inputValues[ 0 ];
-        return c instanceof Boolean ? (Boolean) c : Boolean.FALSE;
+    public Function<Object[],Boolean> inputStorage( ValueInfo[] infos,
+                                                    DomainMapper[] dms ) {
+        return userValues -> {
+            Object c = userValues[ 0 ];
+            return c instanceof Boolean ? (Boolean) c : Boolean.FALSE;
+        };
     }
 
     /**
