@@ -1,6 +1,6 @@
 package uk.ac.starlink.ttools.plot2.data;
 
-import uk.ac.starlink.table.DomainMapper;
+import uk.ac.starlink.table.Domain;
 
 /**
  * Partial Coord implementation for quantities that are represented
@@ -20,14 +20,12 @@ public abstract class SingleCoord implements Coord {
      *
      * @param   meta   descriptive metadata for single user coordinate
      * @param   isRequired  true if this coordinate is required for plotting
-     * @param   valueClass   class of input coordinate quantity
+     * @param   domain  input coordinate domain
      * @param   storageType  storage type object
-     * @param   domain  DomainMapper subtype for this coord, or null
      */
     protected SingleCoord( InputMeta meta, boolean isRequired,
-                           Class<?> valueClass, StorageType storageType,
-                           Class<? extends DomainMapper> domain ) {
-        input_ = new Input( meta, valueClass, domain );
+                           Domain<?> domain, StorageType storageType ) {
+        input_ = new Input( meta, domain );
         isRequired_ = isRequired;
         storageType_ = storageType;
     }
