@@ -1,6 +1,8 @@
 package uk.ac.starlink.ttools.plot2.data;
 
+import java.util.function.Function;
 import uk.ac.starlink.table.DomainMapper;
+import uk.ac.starlink.table.ValueInfo;
 
 /**
  * Coord implementation for String values.
@@ -10,6 +12,10 @@ import uk.ac.starlink.table.DomainMapper;
  */
 public class StringCoord extends SingleCoord {
 
+    private static final SimpleDomain<String> STRING_DOMAIN =
+        new SimpleDomain<String>( String.class, "String", "string",
+                                  "String value" );
+
     /**
      * Constructor.
      *
@@ -17,12 +23,15 @@ public class StringCoord extends SingleCoord {
      * @param   isRequired  true if this coordinate is required for plotting
      */
     public StringCoord( InputMeta meta, boolean isRequired ) {
-        super( meta, isRequired, Object.class, StorageType.STRING, null );
+        super( meta, isRequired, STRING_DOMAIN, StorageType.STRING );
     }
 
-    public Object inputToStorage( Object[] values, DomainMapper[] mappers ) {
-        Object c = values[ 0 ];
-        return c == null ? "" : c.toString();
+    public Function<Object[],String> inputStorage( ValueInfo[] infos,
+                                                   DomainMapper[] dms ) {
+        return values -> {
+            Object c = values[ 0 ];
+            return c == null ? "" : c.toString();
+        };
     }
 
     /**
