@@ -7,6 +7,8 @@ import uk.ac.starlink.ttools.plot2.DataGeom;
 import uk.ac.starlink.ttools.plot2.PlotType;
 import uk.ac.starlink.ttools.plot2.Plotter;
 import uk.ac.starlink.ttools.plot2.SurfaceFactory;
+import uk.ac.starlink.ttools.plot2.layer.AreaForm;
+import uk.ac.starlink.ttools.plot2.layer.CentralForm;
 import uk.ac.starlink.ttools.plot2.layer.ContourPlotter;
 import uk.ac.starlink.ttools.plot2.layer.HealpixPlotter;
 import uk.ac.starlink.ttools.plot2.layer.LabelPlotter;
@@ -70,12 +72,15 @@ public class SkyPlotType
             PolygonForms.QUAD,
             MarkForm.QUAD,
             PolygonForms.ARRAY,
+            AreaForm.SKY_INSTANCE,
+            CentralForm.SKY_INSTANCE,
         };
         Plotter<?>[] shapePlotters =
             ShapePlotter.createShapePlotters( forms, ShapeMode.MODES_2D );
         list.addAll( Arrays.asList( shapePlotters ) );
         list.addAll( Arrays.asList( new Plotter<?>[] {
-            new LabelPlotter(),
+            LabelPlotter.POINT_INSTANCE,
+            LabelPlotter.AREA_SKY_INSTANCE,
             new ContourPlotter( true ),
             new SkyDensityPlotter( true, true ),
             new HealpixPlotter( true ),
