@@ -1,8 +1,6 @@
 package uk.ac.starlink.ttools.plot2.layer;
 
 import java.awt.Color;
-import java.awt.Graphics;
-import java.awt.Rectangle;
 import java.awt.geom.Point2D;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -14,7 +12,6 @@ import javax.swing.Icon;
 import uk.ac.starlink.table.ValueInfo;
 import uk.ac.starlink.ttools.gui.ResourceIcon;
 import uk.ac.starlink.ttools.plot.ErrorMode;
-import uk.ac.starlink.ttools.plot.ErrorRenderer;
 import uk.ac.starlink.ttools.plot.Pixellator;
 import uk.ac.starlink.ttools.plot2.AuxReader;
 import uk.ac.starlink.ttools.plot2.AuxScale;
@@ -28,6 +25,7 @@ import uk.ac.starlink.ttools.plot2.Span;
 import uk.ac.starlink.ttools.plot2.Surface;
 import uk.ac.starlink.ttools.plot2.config.ConfigKey;
 import uk.ac.starlink.ttools.plot2.config.ConfigMap;
+import uk.ac.starlink.ttools.plot2.config.ConfigMeta;
 import uk.ac.starlink.ttools.plot2.config.MultiPointConfigKey;
 import uk.ac.starlink.ttools.plot2.config.StyleKeys;
 import uk.ac.starlink.ttools.plot2.data.Coord;
@@ -48,10 +46,7 @@ import uk.ac.starlink.ttools.plot2.paper.PaperType3D;
  * The extra coordinates required (defining one or more non-central
  * data positions) are defined by a supplied {@link MultiPointCoordSet}
  * and those coordinates are then plotted by a corresponding
- * {@link uk.ac.starlink.ttools.plot.ErrorRenderer}.
- * ErrorRenderer may be a slightly misleading name in this context, but you
- * can think of any of these multi-point shapes as a generalisation of
- * error bars.
+ * {@link MultiPointShape}.
  *
  * @author   Mark Taylor
  * @since    18 Feb 2013
@@ -62,7 +57,8 @@ public abstract class MultiPointForm implements ShapeForm {
     private final Icon icon_;
     private final String description_;
     private final MultiPointCoordSet extraCoordSet_;
-    private final MultiPointConfigKey rendererKey_;
+    private final MultiPointConfigKey shapeKey_;
+    private final ConfigKey<Integer> thickKey_;
     private final ConfigKey<?>[] otherKeys_;
 
     /**
@@ -73,21 +69,22 @@ public abstract class MultiPointForm implements ShapeForm {
      * @param  description  XML description
      * @param  extraCoordSet  defines the extra positional coordinates 
      *                        used to plot multipoint shapes
-     * @param  rendererKey  config key for the renderer; provides option to
-     *                      vary the shape, but any renderer specified by it
-     *                      must be expecting data corresponding to the
-     *                      <code>extraCoordSet</code> parameter
+     * @param  shapeKey  config key for the shape; provides option to
+     *                   vary the shape, but any shape specified by it
+     *                   must be expecting data corresponding to the
+     *                   <code>extraCoordSet</code> parameter
      * @param  otherKeys    additional config keys
      */
     public MultiPointForm( String name, Icon icon, String description,
                            MultiPointCoordSet extraCoordSet,
-                           MultiPointConfigKey rendererKey,
+                           MultiPointConfigKey shapeKey,
                            ConfigKey<?>[] otherKeys ) {
         name_ = name;
         icon_ = icon;
         description_ = description;
         extraCoordSet_ = extraCoordSet;
-        rendererKey_ = rendererKey;
+        shapeKey_ = shapeKey;
+        thickKey_ = createThicknessKey( shapeKey_ );
         otherKeys_ = otherKeys;
     }
 
@@ -138,18 +135,20 @@ public abstract class MultiPointForm implements ShapeForm {
 
     public ConfigKey<?>[] getConfigKeys() {
         List<ConfigKey<?>> list = new ArrayList<ConfigKey<?>>();
-        list.add( rendererKey_ );
+        list.add( shapeKey_ );
+        list.add( thickKey_ );
         list.addAll( Arrays.asList( otherKeys_ ) );
         return list.toArray( new ConfigKey<?>[ 0 ] );
     }
 
     public Outliner createOutliner( ConfigMap config ) {
-        ErrorRenderer renderer = config.get( rendererKey_ );
-        ErrorMode[] errorModes = rendererKey_.getErrorModes();
+        MultiPointShape shape = config.get( shapeKey_ );
+        int nthick = config.get( thickKey_ ).intValue();
+        ErrorMode[] errorModes = shapeKey_.getErrorModes();
         double scale = getScaleFactor( config );
         boolean isAutoscale = isAutoscale( config );
-        return new MultiPointOutliner( renderer, errorModes, scale,
-                                       isAutoscale );
+        return new MultiPointOutliner( shape, nthick, errorModes,
+                                       scale, isAutoscale );
     }
 
     /**
@@ -219,13 +218,13 @@ public abstract class MultiPointForm implements ShapeForm {
      *
      * @param  name  form name
      * @param  extraCoordSet  coord set specifying error bar position endpoints
-     * @param  rendererKey   config key for specifying error renderers
+     * @param  shapeKey   config key for specifying multipoint shape
      * @return  new error form instance
      */
     public static MultiPointForm
                   createErrorForm( String name,
                                    MultiPointCoordSet extraCoordSet,
-                                   MultiPointConfigKey rendererKey ) {
+                                   MultiPointConfigKey shapeKey ) {
         String descrip = PlotUtil.concatLines( new String[] {
             "<p>Plots symmetric or asymmetric error bars in some or",
             "all of the plot dimensions.",
@@ -235,7 +234,7 @@ public abstract class MultiPointForm implements ShapeForm {
             "</p>",
         } );
         return createDefaultForm( name, ResourceIcon.FORM_ERROR, descrip,
-                                  extraCoordSet, rendererKey, false );
+                                  extraCoordSet, shapeKey, false );
     }
 
     /**
@@ -249,21 +248,21 @@ public abstract class MultiPointForm implements ShapeForm {
      * @param  description  XML description
      * @param  extraCoordSet  defines the extra positional coordinates 
      *                        used to plot multipoint shapes
-     * @param  rendererKey  config key for the renderer; provides option to
-     *                      vary the shape, but any renderer specified by it
-     *                      must be expecting data corresponding to the
-     *                      <code>extraCoordSet</code> parameter
+     * @param  shapeKey  config key for the shape; provides option to
+     *                   vary the shape, but any shape specified by it
+     *                   must be expecting data corresponding to the
+     *                   <code>extraCoordSet</code> parameter
      * @param  canScale   true for standard scaling configuration,
      *                    false for no scaling
      */
     public static MultiPointForm
             createDefaultForm( String name, Icon icon, String description, 
                                MultiPointCoordSet extraCoordSet,
-                               MultiPointConfigKey rendererKey,
+                               MultiPointConfigKey shapeKey,
                                boolean canScale ) {
         if ( canScale ) {
             return new MultiPointForm( name, icon, description, extraCoordSet,
-                                       rendererKey, new ConfigKey<?>[] {
+                                       shapeKey, new ConfigKey<?>[] {
                                            StyleKeys.SCALE, StyleKeys.AUTOSCALE,
                                        } ) {
                 protected double getScaleFactor( ConfigMap config ) {
@@ -276,7 +275,7 @@ public abstract class MultiPointForm implements ShapeForm {
         }
         else {
             return new MultiPointForm( name, icon, description, extraCoordSet,
-                                       rendererKey, new ConfigKey<?>[ 0 ] ) {
+                                       shapeKey, new ConfigKey<?>[ 0 ] ) {
                 protected double getScaleFactor( ConfigMap config ) {
                     return 1;
                 }
@@ -287,6 +286,29 @@ public abstract class MultiPointForm implements ShapeForm {
         }
     }
 
+    /**
+     * Creates a config key for line thickness to be used with
+     * MultiPointShapes.
+     *
+     * @param  shapeKey  configured shape to which this relates
+     * @return  key for line thickness
+     */
+    public static ConfigKey<Integer>
+            createThicknessKey( MultiPointConfigKey shapeKey ) {
+        ConfigMeta meta = new ConfigMeta( "thick", "Thickness" );
+        meta.setShortDescription( "Line thickness for "
+                                + shapeKey.getMeta().getShortDescription() );
+        meta.setXmlDescription( new String[] {
+            "<p>Controls the line thickness used when drawing shapes.",
+            "Zero, the default value, means a 1-pixel-wide line is used.",
+            "Larger values make drawn lines thicker,",
+            "but note changing this value will not affect all shapes,",
+            "for instance filled rectangles contain no line drawings.",
+            "</p>",
+        } );
+        return StyleKeys.createPaintThicknessKey( meta, 3 );
+    }
+
     /**
      * Returns the column index in a tuple sequence at which the
      * extra (multi-point) coordinates start.
@@ -303,7 +325,7 @@ public abstract class MultiPointForm implements ShapeForm {
      * Outliner implementation for use with MultiPointForms.
      */
     private class MultiPointOutliner extends PixOutliner {
-        private final ErrorRenderer renderer_;
+        private final MultiPointScribe scribe_;
         private final ErrorMode[] modes_;
         private final double scale_;
         private final boolean isAutoscale_;
@@ -312,19 +334,21 @@ public abstract class MultiPointForm implements ShapeForm {
         /**
          * Constructor.
          *
-         * @param  renderer  multi-point shape drawer
-         * @param  modes   used with renderer to define icon shape
+         * @param  shape   shape
+         * @param  nthick  line thickness
+         * @param  modes   used with shape to define icon
          * @param  scale   scaling adjustment factor
          * @param  isAutoscale  true if initial size scaling is done
          *                      from the data
          */
-        public MultiPointOutliner( ErrorRenderer renderer, ErrorMode[] modes,
-                                   double scale, boolean isAutoscale ) {
-            renderer_ = renderer;
+        public MultiPointOutliner( MultiPointShape shape, int nthick,
+                                   ErrorMode[] modes, double scale,
+                                   boolean isAutoscale ) {
+            scribe_ = shape.createScribe( nthick );
             modes_ = modes;
             scale_ = scale;
             isAutoscale_ = isAutoscale;
-            icon_ = renderer.getLegendIcon( modes, 14, 10, 1, 1 );
+            icon_ = shape.getLegendIcon( scribe_, modes, 14, 10, 1, 1 );
         }
 
         public Icon getLegendIcon() {
@@ -363,8 +387,7 @@ public abstract class MultiPointForm implements ShapeForm {
                         int[] yoffs = new int[ nextra ];
                         offsetter.calculateOffsets( dpos0, gpos0, dposExtras,
                                                     xoffs, yoffs );
-                        Glyph glyph =
-                            new MultiPointGlyph( renderer_, xoffs, yoffs );
+                        Glyph glyph = scribe_.createGlyph( xoffs, yoffs);
                         paperType.placeGlyph( paper, gpos0.x, gpos0.y,
                                               glyph, color );
                     }
@@ -395,8 +418,7 @@ public abstract class MultiPointForm implements ShapeForm {
                         int[] yoffs = new int[ nextra ];
                         offsetter.calculateOffsets( dpos0, gpos0, dposExtras,
                                                     xoffs, yoffs );
-                        Glyph glyph =
-                            new MultiPointGlyph( renderer_, xoffs, yoffs );
+                        Glyph glyph = scribe_.createGlyph( xoffs, yoffs);
                         paperType.placeGlyph( paper, gpos0.x, gpos0.y, gpos0.z,
                                               glyph, color );
                     }
@@ -408,7 +430,7 @@ public abstract class MultiPointForm implements ShapeForm {
         public boolean equals( Object o ) {
             if ( o instanceof MultiPointOutliner ) {
                 MultiPointOutliner other = (MultiPointOutliner) o;
-                return this.renderer_.equals( other.renderer_ )
+                return this.scribe_.equals( other.scribe_ )
                     && Arrays.equals( this.modes_, other.modes_ )
                     && this.isAutoscale_ == other.isAutoscale_
                     && this.scale_ == other.scale_;
@@ -421,7 +443,7 @@ public abstract class MultiPointForm implements ShapeForm {
         @Override
         public int hashCode() {
             int code = 3203;
-            code = code * 23 + renderer_.hashCode();
+            code = code * 23 + scribe_.hashCode();
             code = code * 23 + Arrays.hashCode( modes_ );
             code = code * 23 + ( isAutoscale_ ? 11 : 13 );
             code = code * 23 + Float.floatToIntBits( (float) scale_ );
@@ -491,7 +513,7 @@ public abstract class MultiPointForm implements ShapeForm {
 
         /**
          * Converts data values read from the tuple sequence into a list
-         * of graphics coordinates suitable for feeding to the ErrorRenderer.
+         * of graphics coordinates suitable for feeding to the MultiPointShape.
          * The result is returned by filling a supplied pair of arrays
          * giving X and Y offsets in graphics coordinates from the
          * (supplied) central point, so (0,0) indicates an extra point
@@ -531,49 +553,6 @@ public abstract class MultiPointForm implements ShapeForm {
         }
     }
 
-    /**
-     * Glyph implementation to draw a multipoint shape.
-     */
-    private static class MultiPointGlyph implements Glyph {
-        private final ErrorRenderer renderer_;
-        private final int[] xoffs_;
-        private final int[] yoffs_;
-
-        /**
-         * Constructor.
-         *
-         * @param  renderer  multipoint shape renderer
-         * @param  xoffs  graphics position X-coordinate offsets
-         * @param  yoffs  graphics position Y-coordinate offsets.
-         */
-        MultiPointGlyph( ErrorRenderer renderer, int[] xoffs, int[] yoffs ) {
-            renderer_ = renderer;
-            xoffs_ = xoffs;
-            yoffs_ = yoffs;
-        }
-
-        public void paintGlyph( Graphics g ) {
-            renderer_.drawErrors( g, 0, 0, xoffs_, yoffs_ );
-        }
-
-        public Pixer createPixer( Rectangle clip ) {
-            final Pixellator pixellator =
-                renderer_.getPixels( clip, 0, 0, xoffs_, yoffs_ );
-            pixellator.start();
-            return new Pixer() {
-                public boolean next() {
-                    return pixellator.next();
-                }
-                public int getX() {
-                    return pixellator.getX();
-                }
-                public int getY() {
-                    return pixellator.getY();
-                }
-            };
-        }
-    }
-
     /**
      * AuxScale key for calculating multipoint shape size ranges.
      * Currently this is non-shared, but it could be shared for
