@@ -28,31 +28,52 @@ import uk.ac.starlink.ttools.plot2.data.DataSpec;
  * @author   Mark Taylor
  * @since    18 Feb 2013
  */
-public class ShapePlotter extends AbstractPlotter<ShapeStyle> {
+public class ShapePlotter extends AbstractPlotter<ShapeStyle>
+                          implements ShapeModePlotter {
 
     private final ShapeForm form_;
     private final ShapeMode mode_;
 
     /**
-     * Constructor.
+     * Constructs a ShapePlotter with a coord group determined from
+     * its supplied form and mode.
      *
      * @param   name  plotter name
      * @param   form  shape determiner
      * @param   mode  colour determiner
      */
     public ShapePlotter( String name, ShapeForm form, ShapeMode mode ) {
-        super( name,
-               form.getFormIcon(),
-               CoordGroup
-              .createCoordGroup( form.getPositionCount(),
-                                 PlotUtil
-                                .arrayConcat( form.getExtraCoords(),
-                                              mode.getExtraCoords() ) ),
-               mode.hasReports() );
+        this( name, form, mode,
+              CoordGroup
+             .createCoordGroup( form.getPositionCount(),
+                                PlotUtil
+                               .arrayConcat( form.getExtraCoords(),
+                                             mode.getExtraCoords() ) ) );
+    }
+
+    /**
+     * Constructs a ShapePlotter with a given coord group.
+     *
+     * @param   name  plotter name
+     * @param   form  shape determiner
+     * @param   mode  colour determiner
+     * @param   cgrp  coordinate group
+     */
+    protected ShapePlotter( String name, ShapeForm form, ShapeMode mode,
+                            CoordGroup cgrp ) {
+        super( name, form.getFormIcon(), cgrp, mode.hasReports() );
         form_ = form;
         mode_ = mode;
     }
 
+    public ShapeForm getForm() {
+        return form_;
+    }
+
+    public ShapeMode getMode() {
+        return mode_;
+    }
+
     public String getPlotterDescription() {
         return PlotUtil.concatLines( new String[] {
             "<p><dl>",
@@ -100,7 +121,7 @@ public class ShapePlotter extends AbstractPlotter<ShapeStyle> {
     public int getModeCoordsIndex( DataGeom geom ) {
         return ( geom == null ? 0 : geom.getPosCoords().length )
                * form_.getPositionCount()
-             + form_.getExtraCoords().length;
+               + form_.getExtraCoords().length;
     }
 
     /**
@@ -113,19 +134,18 @@ public class ShapePlotter extends AbstractPlotter<ShapeStyle> {
      * @param  modes  array of shape modes
      * @return <code>forms.length*modes.length</code>-element array of plotters
      */
-    public static ShapeModePlotter[] createShapePlotters( ShapeForm[] forms,
-                                                          ShapeMode[] modes ) {
+    public static ShapePlotter[] createShapePlotters( ShapeForm[] forms,
+                                                      ShapeMode[] modes ) {
         int nf = forms.length;
         int nm = modes.length;
-        ShapeModePlotter[] plotters = new ShapeModePlotter[ nf * nm ];
+        ShapePlotter[] plotters = new ShapePlotter[ nf * nm ];
         int ip = 0;
         for ( int im = 0; im < nm; im++ ) {
             ShapeMode mode = modes[ im ];
             for ( int jf = 0; jf < nf; jf++ ) {
                 ShapeForm form = forms[ jf ];
                 String name = form.getFormName() + "-" + mode.getModeName();
-                ShapeModePlotter p = new ShapeModePlotter( name, form, mode );
-                plotters[ ip++ ] = p;
+                plotters[ ip++ ] = new ShapePlotter( name, form, mode );
             }
         }
         assert ip == plotters.length;
@@ -144,35 +164,4 @@ public class ShapePlotter extends AbstractPlotter<ShapeStyle> {
     public static ShapePlotter createFlat2dPlotter( ShapeForm form ) {
         return new ShapePlotter( form.getFormName(), form, ShapeMode.FLAT2D );
     }
-
-    /**
-     * ShapePlotter subclass which additionally implements the ModePlotter
-     * interface.
-     */
-    public static class ShapeModePlotter extends ShapePlotter
-                                         implements ModePlotter<ShapeStyle> {
-        private final ShapeForm sform_;
-        private final ShapeMode smode_;
-
-        /**
-         * Constructor.
-         *
-         * @param   name  plotter name
-         * @param   form  shape of markers
-         * @param   mode  compositing mode
-         */
-        public ShapeModePlotter( String name, ShapeForm form, ShapeMode mode ) {
-            super( name, form, mode );
-            sform_ = form;
-            smode_ = mode;
-        }
-
-        public ShapeForm getForm() {
-            return sform_;
-        }
-
-        public ShapeMode getMode() {
-            return smode_;
-        }
-    }
 }
