@@ -94,6 +94,12 @@ class TableTest(unittest.TestCase):
                           self.messier.cmd_addcol('-before', '1', 'Name', 999)
                           [100]['Name'])
 
+    def testScheme(self):
+        self.assertEquals(10, len(stilts.tread(':loop:10')))
+        cliff = stilts.tread(':attractor:11,clifford').cmd_cache()
+        self.assertEquals(11, len(cliff))
+        self.assertEquals(['x','y'], [str(c) for c in cliff.columns()])
+
     def testTasks(self):
         self.assertEquals(99, int(stilts.calc('100-1')))
         self.assertEquals(31,
@@ -124,6 +130,9 @@ class TableTest(unittest.TestCase):
         self.assertRaises(SyntaxError, stilts.calc, '1+2', spurious='99')
         self.assertRaises(uk.ac.starlink.task.UsageException,
                           stilts.tmatchn)
+        lop = stilts.tloop(start=50, end=100, step=10)
+        self.assertEquals(99, len(stilts.tloop(99)))
+        self.assertEquals(5, len(stilts.tloop(start=50, end=100, step=10)))
 
     def testIO(self):
         for fmt in ['csv', 'fits', 'ascii', 'votable']:
